
# Type: todos


Outstanding issue that needs resolution

URI: [meta:todos](https://w3id.org/biolink/biolinkml/meta/todos)


## Domain and Range

[Element](Element.md) ->  <sub>0..*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
